import { Buff } from '@cmdcode/buff';
import { CoreClient } from './client.js';
import { ScriptWord, SigHashOptions, TxData, TxTemplate } from '@scrow/tapscript';
import { AddressConfig, AddressInfo, AddressType, CmdConfig, DescriptorKeyPair, FundingOptions, MethodArgs, TxPrevout, UTXO, WalletConfig, WalletInfo } from '../types/index.js';
export declare class CoreWallet {
    readonly _addrs: Map<string, string>;
    readonly _client: CoreClient;
    readonly _config: WalletConfig;
    readonly _label: string;
    _txfee?: number | null;
    constructor(client: CoreClient, label: string, config?: WalletConfig);
    get client(): CoreClient;
    get info(): Promise<WalletInfo>;
    get is_created(): Promise<boolean>;
    get is_loaded(): Promise<boolean>;
    get label(): string;
    get balance(): Promise<number>;
    get network(): string;
    get new_address(): Promise<string>;
    get new_scriptkey(): Promise<ScriptWord[]>;
    get utxos(): Promise<{
        sats: number;
        txid: string;
        vout: number;
        address: string;
        label: string;
        scriptPubKey: string;
        amount: number;
        confirmations: number;
        spendable: boolean;
        solvable: boolean;
        desc: string;
        parent_descs: string[];
        safe: boolean;
    }[]>;
    get xprvs(): Promise<import("../types/descriptors.js").DescriptorData[]>;
    get xpubs(): Promise<import("../types/descriptors.js").DescriptorData[]>;
    get xprv(): Promise<string>;
    get xpub(): Promise<string>;
    _debug(...msg: unknown[]): void;
    _log(...msg: unknown[]): void;
    _create(): Promise<void>;
    _load(): Promise<void>;
    init(): Promise<void>;
    load(): Promise<void>;
    cmd<T = Record<string, string>>(method: string, args?: MethodArgs, config?: Partial<CmdConfig>): Promise<T>;
    gen_address(config?: AddressConfig): Promise<string>;
    get_address(label: string, type?: AddressType): Promise<string>;
    parse_address(address: string): Promise<AddressInfo>;
    get_pubkey(address: string): Promise<string>;
    gen_pubkey(config: AddressConfig): Promise<string>;
    get_descriptor(address: string): Promise<DescriptorKeyPair>;
    gen_descriptor(config: AddressConfig): Promise<DescriptorKeyPair>;
    send_funds(amount: number, address: string, mine_block?: boolean): Promise<string>;
    ensure_funds(min_bal: number): Promise<void>;
    drain_faucet(amount: number, address?: string): Promise<string>;
    get_xprv(label: string): Promise<import("../types/descriptors.js").DescriptorData | undefined>;
    get_signer(desc: string): Promise<{
        pubkey: Buff;
        sign_tx: (txdata: TxData, config: SigHashOptions) => Buff;
    }>;
    create_utxo(amount: number, address: string, mine_block?: boolean): Promise<TxPrevout>;
    select_utxos(amount: number, sorter?: () => 1 | -1): Promise<UTXO[]>;
    fund_tx(template: TxTemplate, config?: SigHashOptions, txfee?: number): Promise<TxData>;
    add_segwit_desc(psbt: string, pubkey: string, index: number): Promise<string>;
    add_taproot_desc(psbt: string, pubkey: string, index: number, scripts?: string[], version?: number): Promise<string>;
    fund_psbt(psbt: string, options?: FundingOptions): Promise<string>;
    sign_psbt(psbt: string): Promise<string>;
}
//# sourceMappingURL=wallet.d.ts.map